@@ -2,6 +2,7 @@ package App::Ack;
 
 use warnings;
 use strict;
+use File::Basename;
 
 =head1 NAME
 
@@ -9,11 +10,36 @@ App::Ack - A container for functions for the ack program
 
 =head1 VERSION
 
-Version 1.26
+Version 1.28
 
 =cut
 
-our $VERSION = '1.26';
+our $VERSION = '1.28';
+
+our %mappings = (
+    asm         => [qw( s S )],
+    binary      => q{Binary files, as defined by Perl's -B op (default: off)},
+    cc          => [qw( c h )],
+    css         => [qw( css )],
+    elisp       => [qw( el )],
+    haskell     => [qw( hs lhs )],
+    html        => [qw( htm html shtml )],
+    lisp        => [qw( lisp )],
+    js          => [qw( js )],
+    mason       => [qw( mas )],
+    ocaml       => [qw( ml mli )],
+    parrot      => [qw( pir pasm pmc ops pod pg tg )],
+    perl        => [qw( pl pm pod tt ttml t )],
+    php         => [qw( php phpt htm html )],
+    python      => [qw( py )],
+    ruby        => [qw( rb rhtml rjs )],
+    scheme      => [qw( scm )],
+    shell       => [qw( sh bash csh ksh zsh )],
+    sql         => [qw( sql ctl )],
+    tt          => [qw( tt tt2 )],
+    vim         => [qw( vim )],
+    yaml        => [qw( yaml yml )],
+);
 
 =head1 SYNOPSIS
 
@@ -56,39 +82,21 @@ sub skipdir_filter {
 }
 
 our %types;
-our %mappings = (
-    asm         => [qw( s S )],
-    binary      => q{Binary files, as defined by Perl's -B op (default: off)},
-    cc          => [qw( c h )],
-    css         => [qw( css )],
-    elisp       => [qw( el )],
-    haskell     => [qw( hs lhs )],
-    html        => [qw( htm html shtml )],
-    lisp        => [qw( lisp )],
-    js          => [qw( js )],
-    ocaml       => [qw( ml mli )],
-    parrot      => [qw( pir pasm pmc ops pod pg tg )],
-    perl        => [qw( pl pm pod tt ttml t )],
-    php         => [qw( php phpt htm html )],
-    python      => [qw( py )],
-    ruby        => [qw( rb rhtml rjs )],
-    scheme      => [qw( scm )],
-    shell       => [qw( sh bash csh ksh zsh )],
-    sql         => [qw( sql ctl )],
-    tt          => [qw( tt tt2 )],
-    vim         => [qw( vim )],
-    yaml        => [qw( yaml yml )],
-);
+our @suffixes;
 
 sub _init_types {
+    my %suffixes;
     while ( my ($type,$exts) = each %mappings ) {
         if ( ref $exts ) {
             for my $ext ( @$exts ) {
                 push( @{$types{$ext}}, $type );
+                ++$suffixes{"\\.$ext"};
             }
         }
     }
 
+    @suffixes = keys %suffixes;
+
     return;
 }
 
@@ -105,9 +113,18 @@ sub filetypes {
 
     _init_types() unless keys %types;
 
+    return '-ignore' if $filename =~ /~$/;
+
+    # Pass our $filename in lowercase so we match lowercase filenames
+    my ($filebase,$dirs,$suffix) = File::Basename::fileparse( lc $filename, @suffixes );
+
+    return '-ignore' if $filebase =~ /^#.+#$/;
+    return '-ignore' if $filebase =~ /^core\.\d+$/;
+
     # If there's an extension, look it up
-    if ( $filename =~ /\.([^.]+)$/ ) {
-        my $ref = $types{lc $1};
+    if ( $suffix ) {
+        $suffix =~ s/^\.//; # Drop the period that File::Basename needs
+        my $ref = $types{lc $suffix};
         return @$ref if $ref;
     }
 
@@ -162,6 +179,7 @@ sub show_help {
 
     my @langlines;
     for my $lang ( sort keys %mappings ) {
+        next if $lang =~ /^-/; # Stuff to not show
         my $ext_list = $mappings{$lang};
 
         if ( ref $ext_list ) {
